==> purchase-assist-domain-0.0.7-sources.jar: com/xforceplus/purchaserassist/entity/InvoiceCollectionInfo.java <==
package com.xforceplus.purchaserassist.entity;

import java.math.BigDecimal;
import com.baomidou.mybatisplus.annotation.TableName;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-03-17
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("invoiceCollectionInfo")
public class InvoiceCollectionInfo implements Serializable {

  private static final long serialVersionUID=1L;

  private String collectionName;

  private LocalDateTime collectionTime;

  private BigDecimal collectionAmount;

  private Integer collectionNum;

  private Integer colllectionRepeatFlag;

  private Integer collectionOccupiedFlag;

  private String collectionExceptionDesc;

  private Integer collectionExceptionFlag;

  private Integer collectionVerifyFlag;

  private String collectionType;

  private LocalDateTime upateTime;

  private Integer collectionStatus;

  private String collectionNo;

  private Long userId;

  private String orgCode;

  private String invoiceNo;

  private String invoiceCode;

  private BigDecimal invoiceAmount;

  private Integer invoiceStatus;

  private LocalDateTime invoiceTime;

  private String invoiceType;

  private String invoiceTitle;

  private String invoiceUiqFlag;

  private String documentType;

  private Integer discernStatus;

  private String imagUrl;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private String createUser;

  private String updateUser;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;




        }

==> purchase-assist-domain-0.0.14-sources.jar: com/xforceplus/purchaserassist/entity/InvoiceCollectionInfo.java <==
package com.xforceplus.purchaserassist.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-04-02
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class InvoiceCollectionInfo implements Serializable {

  private static final long serialVersionUID=1L;

  private String collectionName;

  private LocalDateTime collectionTime;

  private BigDecimal collectionAmount;

  private Integer collectionNum;

  private Integer colllectionRepeatFlag;

  private Integer collectionOccupiedFlag;

  private String collectionExceptionDesc;

  private Integer collectionExceptionFlag;

  private Integer collectionVerifyFlag;

  private String collectionType;

  private LocalDateTime upateTime;

  private Integer collectionStatus;

  private String collectionNo;

  private Long userId;

  private String orgCode;

  private String invoiceNo;

  private String invoiceCode;

  private BigDecimal invoiceAmount;

  private Integer invoiceStatus;

  private LocalDateTime invoiceTime;

  private String invoiceType;

  private String invoiceTitle;

  private String invoiceUiqFlag;

  private String documentType;

  private Integer discernStatus;

  private String imagUrl;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;




        }
